@@ -100,7 +100,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
     def _cursor(self):
         if self.connection is None:
             self.__connect()
-        return Database.Cursor(self.connection)
+        return self.connection.cursor()
 
     def disable_constraint_checking(self):
         """
